@@ -30,10 +30,10 @@
 #define KP_DOCUMENT_H
 
 
-#include <qbitmap.h>
-#include <qobject.h>
-#include <qstring.h>
-#include <qurl.h>
+#include <QBitmap>
+#include <QObject>
+#include <QString>
+#include <QUrl>
 
 #include "imagelib/kpImage.h"
 #include "pixmapfx/kpPixmapFX.h"
@@ -311,7 +311,6 @@ public:
 public slots:
     // these will emit signals!
     void slotContentsChanged (const QRect &rect);
-    void slotSizeChanged (int newWidth, int newHeight);
     void slotSizeChanged (const QSize &newSize);
 
 signals:
