@@ -29,12 +29,12 @@
 #include "kpMainWindow.h"
 #include "kpMainWindowPrivate.h"
 
-#include <qapplication.h>
-#include <qclipboard.h>
-#include <qfontmetrics.h>
-#include <qimage.h>
-#include <qlist.h>
-#include <qmenu.h>
+#include <QApplication>
+#include <QClipboard>
+#include <QFontMetrics>
+#include <QImage>
+#include <QList>
+#include <QMenu>
 #include <QDesktopWidget>
 #include <QScrollBar>
 
@@ -94,14 +94,14 @@ void kpMainWindow::setupEditMenuActions ()
     d->actionPaste = KStandardAction::paste (this, SLOT (slotPaste()), ac);
     d->actionPasteInNewWindow = ac->addAction ("edit_paste_in_new_window");
     d->actionPasteInNewWindow->setText (i18n ("Paste in &New Window"));
-    connect (d->actionPasteInNewWindow, SIGNAL (triggered(bool)),
-        SLOT (slotPasteInNewWindow()));
+    connect (d->actionPasteInNewWindow, &QAction::triggered,
+             this, &kpMainWindow::slotPasteInNewWindow);
     ac->setDefaultShortcut (d->actionPasteInNewWindow, Qt::CTRL + Qt::SHIFT + Qt::Key_V);
 
     //d->actionDelete = KStandardAction::clear (this, SLOT (slotDelete()), ac);
     d->actionDelete = ac->addAction ("edit_clear");
     d->actionDelete->setText (i18n ("&Delete Selection"));
-    connect (d->actionDelete, SIGNAL (triggered(bool)), SLOT (slotDelete()));
+    connect (d->actionDelete, &QAction::triggered, this, &kpMainWindow::slotDelete);
 
     d->actionSelectAll = KStandardAction::selectAll (this, SLOT (slotSelectAll()), ac);
     d->actionDeselect = KStandardAction::deselect (this, SLOT (slotDeselect()), ac);
@@ -109,12 +109,11 @@ void kpMainWindow::setupEditMenuActions ()
 
     d->actionCopyToFile = ac->addAction ("edit_copy_to_file");
     d->actionCopyToFile->setText (i18n ("C&opy to File..."));
-    connect (d->actionCopyToFile, SIGNAL (triggered(bool)),
-        SLOT (slotCopyToFile()));
+    connect (d->actionCopyToFile, &QAction::triggered, this, &kpMainWindow::slotCopyToFile);
+
     d->actionPasteFromFile = ac->addAction ("edit_paste_from_file");
     d->actionPasteFromFile->setText (i18n ("Paste &From File..."));
-    connect (d->actionPasteFromFile, SIGNAL (triggered(bool)),
-        SLOT (slotPasteFromFile()));
+    connect (d->actionPasteFromFile, &QAction::triggered, this, &kpMainWindow::slotPasteFromFile);
 
 
     d->editMenuDocumentActionsEnabled = false;
@@ -122,8 +121,9 @@ void kpMainWindow::setupEditMenuActions ()
 
     // Paste should always be enabled, as long as there is something to paste
     // (independent of whether we have a document or not)
-    connect (QApplication::clipboard (), SIGNAL (dataChanged()),
-             this, SLOT (slotEnablePaste()));
+    connect (QApplication::clipboard(), &QClipboard::dataChanged,
+             this, &kpMainWindow::slotEnablePaste);
+
     slotEnablePaste ();
 }
 
@@ -183,7 +183,7 @@ void kpMainWindow::slotCut ()
 
 static QMimeData *NewTextMimeData (const QString &text)
 {
-    QMimeData *md = new QMimeData ();
+    auto *md = new QMimeData ();
     md->setText (text);
     return md;
 }
@@ -207,7 +207,7 @@ void kpMainWindow::slotCopy ()
 
     if (dynamic_cast <kpTextSelection *> (sel))
     {
-        kpTextSelection *textSel = static_cast <kpTextSelection *> (sel);
+        auto *textSel = dynamic_cast <kpTextSelection *> (sel);
         if (!textSel->text ().isEmpty ())
         {
             QApplication::clipboard ()->setMimeData (
@@ -238,8 +238,7 @@ void kpMainWindow::slotCopy ()
     }
     else if (dynamic_cast <kpAbstractImageSelection *> (sel))
     {
-        kpAbstractImageSelection *imageSel =
-            static_cast <kpAbstractImageSelection *> (sel);
+        auto *imageSel = dynamic_cast <kpAbstractImageSelection *> (sel);
 
         // Transparency doesn't get sent across the aether so nuke it now
         // so that transparency mask doesn't get needlessly recalculated
@@ -248,10 +247,12 @@ void kpMainWindow::slotCopy ()
 
         kpImage rawImage;
 
-        if (imageSel->hasContent ())
+        if (imageSel->hasContent ()) {
             rawImage = imageSel->baseImage ();
-        else
+        }
+        else {
             rawImage = d->document->getSelectedBaseImage ();
+        }
 
         imageSel->setBaseImage ( rawImage );
 
@@ -259,8 +260,9 @@ void kpMainWindow::slotCopy ()
             new kpSelectionDrag (*imageSel),
             QClipboard::Clipboard);
     }
-    else
+    else {
         Q_ASSERT (!"Unknown selection type");
+    }
 
     delete sel;
 }
@@ -289,8 +291,7 @@ QRect kpMainWindow::calcUsefulPasteRect (int imageWidth, int imageHeight)
 #if DEBUG_KP_MAIN_WINDOW && 1
     qCDebug(kpLogMainWindow) << "kpMainWindow::calcUsefulPasteRect("
                << imageWidth << "," << imageHeight
-               << ")"
-               << endl;
+               << ")";
 #endif
     Q_ASSERT (d->document);
 
@@ -308,12 +309,11 @@ QRect kpMainWindow::calcUsefulPasteRect (int imageWidth, int imageHeight)
             imageWidth <= docTopLeft.x () ||
             imageHeight <= docTopLeft.y ())
         {
-            return QRect (docTopLeft.x (), docTopLeft.y (),
-                          imageWidth, imageHeight);
+            return  {docTopLeft.x (), docTopLeft.y (),  imageWidth, imageHeight};
         }
     }
 
-    return QRect (0, 0, imageWidth, imageHeight);
+    return  {0, 0, imageWidth, imageHeight};
 }
 
 //---------------------------------------------------------------------
@@ -322,8 +322,7 @@ QRect kpMainWindow::calcUsefulPasteRect (int imageWidth, int imageHeight)
 void kpMainWindow::paste(const kpAbstractSelection &sel, bool forceTopLeft)
 {
 #if DEBUG_KP_MAIN_WINDOW && 1
-    qCDebug(kpLogMainWindow) << "kpMainWindow::paste(forceTopLeft=" << forceTopLeft << ")"
-               << endl;
+    qCDebug(kpLogMainWindow) << "kpMainWindow::paste(forceTopLeft=" << forceTopLeft << ")";
 #endif
 
     kpSetOverrideCursorSaver cursorSaver (Qt::WaitCursor);
@@ -336,7 +335,7 @@ void kpMainWindow::paste(const kpAbstractSelection &sel, bool forceTopLeft)
 
     if (!d->document)
     {
-        kpDocument *newDoc = new kpDocument (
+        auto *newDoc = new kpDocument (
             sel.width (), sel.height (), documentEnvironment ());
 
         // will also create viewManager
@@ -347,16 +346,17 @@ void kpMainWindow::paste(const kpAbstractSelection &sel, bool forceTopLeft)
     // Paste as new selection
     //
 
-    const kpAbstractImageSelection *imageSel =
-        dynamic_cast <const kpAbstractImageSelection *> (&sel);
+    const auto *imageSel = dynamic_cast <const kpAbstractImageSelection *> (&sel);
+
     if (imageSel && imageSel->hasContent () && imageSel->transparency ().isTransparent ())
     {
         d->colorToolBar->flashColorSimilarityToolBarItem ();
     }
 
     kpAbstractSelection *selInUsefulPos = sel.clone ();
-    if (!forceTopLeft)
+    if (!forceTopLeft) {
         selInUsefulPos->moveTo (calcUsefulPasteRect (sel.width (), sel.height ()).topLeft ());
+    }
     // TODO: Should use kpCommandHistory::addCreateSelectionCommand(),
     //       as well, to really support pasting selection borders.
     addDeselectFirstCommand (new kpToolSelectionCreateCommand (
@@ -371,8 +371,7 @@ void kpMainWindow::paste(const kpAbstractSelection &sel, bool forceTopLeft)
 #if DEBUG_KP_MAIN_WINDOW && 1
     qCDebug(kpLogMainWindow) << "sel.size=" << QSize (sel.width (), sel.height ())
                << " document.size="
-               << QSize (d->document->width (), d->document->height ())
-               << endl;
+               << QSize (d->document->width (), d->document->height ());
 #endif
 
     // If the selection is bigger than the document, automatically
@@ -405,11 +404,12 @@ void kpMainWindow::pasteText (const QString &text,
     qCDebug(kpLogMainWindow) << "kpMainWindow::pasteText(" << text
                << ",forceNewTextSelection=" << forceNewTextSelection
                << ",newTextSelectionTopLeft=" << newTextSelectionTopLeft
-               << ")" << endl;
+               << ")";
 #endif
 
-    if ( text.isEmpty() )
+    if ( text.isEmpty() ) {
         return;
+    }
 
     kpSetOverrideCursorSaver cursorSaver (Qt::WaitCursor);
 
@@ -455,7 +455,7 @@ void kpMainWindow::pasteText (const QString &text,
             macroCmd->addCommand (giveContentCmd);
         }
 
-        for (int i = 0; i < (int) textLines.size (); i++)
+        for (int i = 0; i < static_cast<int> (textLines.size ()); i++)
         {
             if (i > 0)
             {
@@ -491,8 +491,9 @@ void kpMainWindow::pasteText (const QString &text,
         const QFontMetrics fontMetrics = ts.fontMetrics ();
 
         int height = textLines.size () * fontMetrics.height ();
-        if (textLines.size () >= 1)
+        if (textLines.size () >= 1) {
             height += (textLines.size () - 1) * fontMetrics.leading ();
+        }
 
         int width = 0;
         for (QList <QString>::const_iterator it = textLines.constBegin ();
@@ -500,8 +501,9 @@ void kpMainWindow::pasteText (const QString &text,
              ++it)
         {
             const int w = fontMetrics.width (*it);
-            if (w > width)
+            if (w > width) {
                 width = w;
+            }
         }
 
         // limit the size to avoid memory overflow
@@ -539,7 +541,7 @@ void kpMainWindow::pasteTextAt (const QString &text, const QPoint &point,
                << ",point=" << point
                << ",allowNewTextSelectionPointShift="
                << allowNewTextSelectionPointShift
-               << ")" << endl;
+               << ")";
 #endif
 
     kpSetOverrideCursorSaver cursorSaver (Qt::WaitCursor);
@@ -638,7 +640,7 @@ void kpMainWindow::slotPasteInNewWindow ()
     // Requirement 2. transparent pixels in the image must remain as transparent.
     //
 
-    kpMainWindow *win = new kpMainWindow (nullptr/*no document*/);
+    auto *win = new kpMainWindow (nullptr/*no document*/);
     win->show ();
 
     // Make "Edit / Paste in New Window" always paste white pixels as white.
@@ -711,16 +713,18 @@ void kpMainWindow::slotSelectAll ()
 
     toolEndShape ();
 
-    if (d->document->selection ())
+    if (d->document->selection ()) {
         slotDeselect ();
+    }
 
     // just the border - don't actually pull image from doc yet
     d->document->setSelection (
         kpRectangularImageSelection (d->document->rect (),
             imageSelectionTransparency ()));
 
-    if (tool ())
+    if (tool ()) {
         tool ()->somethingBelowTheCursorChanged ();
+    }
 }
 
 //---------------------------------------------------------------------
@@ -731,8 +735,7 @@ void kpMainWindow::addDeselectFirstCommand (kpCommand *cmd)
 #if DEBUG_KP_MAIN_WINDOW && 1
     qCDebug(kpLogMainWindow) << "kpMainWindow::addDeselectFirstCommand("
                << cmd
-               << ")"
-               << endl;
+               << ")";
 #endif
 
 
@@ -752,11 +755,13 @@ void kpMainWindow::addDeselectFirstCommand (kpCommand *cmd)
             qCDebug(kpLogMainWindow) << "\tjust a fresh border - was nop - delete";
         #endif
             d->document->selectionDelete ();
-            if (tool ())
+            if (tool ()) {
                 tool ()->somethingBelowTheCursorChanged ();
+            }
 
-            if (cmd)
+            if (cmd) {
                 d->commandHistory->addCommand (cmd);
+            }
         }
         else
         {
@@ -778,14 +783,16 @@ void kpMainWindow::addDeselectFirstCommand (kpCommand *cmd)
                 macroCmd->addCommand (cmd);
                 d->commandHistory->addCommand (macroCmd);
             }
-            else
+            else {
                 d->commandHistory->addCommand (deselectCommand);
+            }
         }
     }
     else
     {
-        if (cmd)
+        if (cmd) {
             d->commandHistory->addCommand (cmd);
+        }
     }
 }
 
@@ -816,8 +823,9 @@ void kpMainWindow::slotCopyToFile ()
     toolEndShape ();
 
 
-    if (!d->document->selection ())
+    if (!d->document->selection ()) {
         return;
+    }
 
     kpImage imageToSave;
 
@@ -832,15 +840,17 @@ void kpMainWindow::slotCopyToFile ()
             // image.
             imageToSave = d->document->getSelectedBaseImage ();
         }
-        else
+        else {
             imageToSave = imageSel->transparentImage ();
+        }
     }
     else if (d->document->textSelection ())
     {
         imageToSave = d->document->textSelection ()->approximateImage ();
     }
-    else
+    else {
         Q_ASSERT (!"Unknown selection type");
+    }
 
 
     kpDocumentSaveOptions chosenSaveOptions;
@@ -857,8 +867,9 @@ void kpMainWindow::slotCopyToFile ()
                                     &allowOverwritePrompt,
                                     &allowLossyPrompt);
 
-    if (chosenURL.isEmpty ())
+    if (chosenURL.isEmpty ()) {
         return;
+    }
 
 
     if (!kpDocument::savePixmapToFile (imageToSave,
@@ -896,8 +907,9 @@ void kpMainWindow::slotPasteFromFile ()
     QList<QUrl> urls = askForOpenURLs(i18nc ("@title:window", "Paste From File"),
                                      false/*only 1 URL*/);
 
-    if (urls.count () != 1)
+    if (urls.count () != 1) {
         return;
+    }
 
     QUrl url = urls.first ();
 
@@ -905,8 +917,9 @@ void kpMainWindow::slotPasteFromFile ()
         false/*show error message if doesn't exist*/,
         this);
 
-    if (image.isNull ())
+    if (image.isNull ()) {
         return;
+    }
 
     addRecentURL (url);
 
