@@ -74,10 +74,11 @@ static int ZoomLevelFromString (const QString &stringIn)
     qCDebug(kpLogMainWindow) << "\tzoomLevel=" << zoomLevel;
 #endif
 
-    if (!ok || zoomLevel < kpView::MinZoomLevel || zoomLevel > kpView::MaxZoomLevel)
+    if (!ok || zoomLevel < kpView::MinZoomLevel || zoomLevel > kpView::MaxZoomLevel) {
         return 0;  // error
-    else
-        return zoomLevel;
+    }
+
+    return zoomLevel;
 }
 
 //---------------------------------------------------------------------
@@ -107,7 +108,9 @@ void kpMainWindow::setupViewMenuZoomActions ()
 
     d->actionZoom = ac->add <KSelectAction> ("view_zoom_to");
     d->actionZoom->setText (i18n ("&Zoom"));
-    connect (d->actionZoom, SIGNAL (triggered(QAction*)), SLOT (slotZoom()));
+    connect (d->actionZoom,
+             static_cast<void (KSelectAction::*)(QAction*)>(&KSelectAction::triggered),
+             this, &kpMainWindow::slotZoom);
     d->actionZoom->setEditable (true);
 
     // create the zoom list for the 1st call to zoomTo() below
@@ -164,8 +167,9 @@ void kpMainWindow::sendZoomListToActionZoom ()
     // KRecentFilesAction.
     bool e = d->actionZoom->isEnabled ();
     d->actionZoom->setItems (items);
-    if (e != d->actionZoom->isEnabled ())
+    if (e != d->actionZoom->isEnabled ()) {
         d->actionZoom->setEnabled (e);
+    }
 }
 
 //---------------------------------------------------------------------
@@ -182,32 +186,18 @@ void kpMainWindow::zoomToPre (int zoomLevel)
 
     zoomLevel = qBound (kpView::MinZoomLevel, zoomLevel, kpView::MaxZoomLevel);
 
-// mute point since the thumbnail suffers from this too
-#if 0
-    else if (d->mainView && d->mainView->zoomLevelX () % 100 == 0 && zoomLevel % 100)
-    {
-        if (KMessageBox::warningContinueCancel (this,
-            i18n ("Setting the zoom level to a value that is not a multiple of 100% "
-                  "results in imprecise editing and redraw glitches.\n"
-                  "Do you really want to set to zoom level to %1%?",
-                  zoomLevel),
-            QString()/*caption*/,
-            i18n ("Set Zoom Level to %1%", zoomLevel),
-            "DoNotAskAgain_ZoomLevelNotMultipleOf100") != KMessageBox::Continue)
-        {
-            zoomLevel = d->mainView->zoomLevelX ();
-        }
-    }
-#endif
-
     int index = 0;
     QList <int>::Iterator it = d->zoomList.begin ();
 
-    while (index < (int) d->zoomList.count () && zoomLevel > *it)
-        it++, index++;
+    while (index < d->zoomList.count () && zoomLevel > *it)
+    {
+        it++;
+        index++;
+    }
 
-    if (zoomLevel != *it)
+    if (zoomLevel != *it) {
         d->zoomList.insert (it, zoomLevel);
+    }
 
     // OPT: We get called twice on startup.  sendZoomListToActionZoom() is very slow.
     sendZoomListToActionZoom ();
@@ -222,8 +212,7 @@ void kpMainWindow::zoomToPre (int zoomLevel)
               << " action="
               << d->actionZoom->action (d->actionZoom->currentItem ())
               << " checkedAction"
-              << d->actionZoom->selectableActionGroup ()->checkedAction ()
-              << endl;;
+              << d->actionZoom->selectableActionGroup ()->checkedAction ();
 #endif
 
 
@@ -231,14 +220,15 @@ void kpMainWindow::zoomToPre (int zoomLevel)
     {
         d->actionActualSize->setEnabled (zoomLevel != 100);
 
-        d->actionZoomIn->setEnabled (d->actionZoom->currentItem () < (int) d->zoomList.count () - 1);
+        d->actionZoomIn->setEnabled (d->actionZoom->currentItem () < d->zoomList.count () - 1);
         d->actionZoomOut->setEnabled (d->actionZoom->currentItem () > 0);
     }
 
 
     // TODO: Is this actually needed?
-    if (d->viewManager)
+    if (d->viewManager) {
         d->viewManager->setQueueUpdates ();
+    }
 
     if (d->scrollView)
     {
@@ -269,8 +259,9 @@ void kpMainWindow::zoomToPost ()
 
 
     // The view magnified and moved beneath the cursor
-    if (tool ())
+    if (tool ()) {
         tool ()->somethingBelowTheCursorChanged ();
+    }
 
 
     if (d->scrollView)
@@ -280,8 +271,9 @@ void kpMainWindow::zoomToPost ()
         d->scrollView->setUpdatesEnabled (true);
     }
 
-    if (d->viewManager && d->viewManager->queueUpdates ()/*just in case*/)
+    if (d->viewManager && d->viewManager->queueUpdates ()/*just in case*/) {
         d->viewManager->restoreQueueUpdates ();
+    }
 
     setStatusBarZoom (d->mainView ? d->mainView->zoomLevelX () : 0);
 
@@ -309,8 +301,7 @@ void kpMainWindow::zoomTo (int zoomLevel, bool centerUnderCursor)
                    << " visibleHeight=" << d->scrollView->viewport()->height ()
                    << " oldZoomX=" << d->mainView->zoomLevelX ()
                    << " oldZoomY=" << d->mainView->zoomLevelY ()
-                   << " newZoom=" << zoomLevel
-                  << endl;
+                   << " newZoom=" << zoomLevel;
     #endif
 
         // TODO: when changing from no scrollbars to scrollbars, Qt lies about
@@ -340,8 +331,9 @@ void kpMainWindow::zoomTo (int zoomLevel, bool centerUnderCursor)
             targetDocY = vuc->transformViewToDocY (viewPoint.y ());
             targetDocAvail = true;
 
-            if (vuc != d->mainView)
+            if (vuc != d->mainView) {
                 viewPoint = vuc->transformViewToOtherView (viewPoint, d->mainView);
+            }
 
             viewX = viewPoint.x ();
             viewY = viewPoint.y ();
@@ -365,10 +357,9 @@ void kpMainWindow::zoomTo (int zoomLevel, bool centerUnderCursor)
 
     #if DEBUG_KP_MAIN_WINDOW && 1
         qCDebug(kpLogMainWindow) << "\tvisibleWidth=" << d->scrollView->viewport()->width ()
-                    << " visibleHeight=" << d->scrollView->viewport()->height ()
-                    << endl;
+                    << " visibleHeight=" << d->scrollView->viewport()->height ();
         qCDebug(kpLogMainWindow) << "\tnewCenterX=" << newCenterX
-                    << " newCenterY=" << newCenterY << endl;
+                    << " newCenterY=" << newCenterY;
     #endif
 
         d->scrollView->horizontalScrollBar()->setValue(newCenterX - (d->scrollView->viewport()->width() / 2));
@@ -385,18 +376,17 @@ void kpMainWindow::zoomTo (int zoomLevel, bool centerUnderCursor)
 
         #if DEBUG_KP_MAIN_WINDOW
             qCDebug(kpLogMainWindow) << "\tcenterUnderCursor: reposition cursor; viewUnderCursor="
-                       << vuc->objectName () << endl;
+                       << vuc->objectName ();
         #endif
 
-            const double viewX = vuc->transformDocToViewX (targetDocX);
-            const double viewY = vuc->transformDocToViewY (targetDocY);
+            const auto viewX = vuc->transformDocToViewX (targetDocX);
+            const auto viewY = vuc->transformDocToViewY (targetDocY);
             // Rounding error from zooming in and out :(
             // TODO: do everything in terms of tool doc points in type "double".
-            const QPoint viewPoint ((int) viewX, (int) viewY);
+            const QPoint viewPoint (static_cast<int> (viewX), static_cast<int> (viewY));
         #if DEBUG_KP_MAIN_WINDOW
             qCDebug(kpLogMainWindow) << "\t\tdoc: (" << targetDocX << "," << targetDocY << ")"
-                       << " viewUnderCursor: (" << viewX << "," << viewY << ")"
-                       << endl;
+                       << " viewUnderCursor: (" << viewX << "," << viewY << ")";
         #endif
 
             if (vuc->visibleRegion ().contains (viewPoint))
@@ -432,8 +422,7 @@ void kpMainWindow::zoomTo (int zoomLevel, bool centerUnderCursor)
             else
             {
             #if DEBUG_KP_MAIN_WINDOW
-                qCDebug(kpLogMainWindow) << "\t\twon't move cursor - would get outside view"
-                           << endl;
+                qCDebug(kpLogMainWindow) << "\t\twon't move cursor - would get outside view";
             #endif
 
                 // TODO: Sane cursor flashing indication that indicates
@@ -444,7 +433,7 @@ void kpMainWindow::zoomTo (int zoomLevel, bool centerUnderCursor)
     #if DEBUG_KP_MAIN_WINDOW && 1
         qCDebug(kpLogMainWindow) << "\t\tcheck (contentsX=" << d->scrollView->horizontalScrollBar()->value ()
                     << ",contentsY=" << d->scrollView->verticalScrollBar()->value ()
-                    << ")" << endl;
+                    << ")";
     #endif
     }
 
@@ -520,6 +509,7 @@ void kpMainWindow::zoomToRect (const QRect &normalizedDocRect,
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "\tzoomX=" << zoomX
         << " zoomY=" << zoomY
+        << " -> zoomLevel=" << zoomLevel;
         << " -> zoomLevel=" << zoomLevel << endl;
 #endif
 
@@ -567,9 +557,9 @@ void kpMainWindow::slotFitToWidth ()
   {
     const QRect docRect (
         0/*x*/,
-        (int) d->mainView->transformViewToDocY (d->scrollView->verticalScrollBar()->value ())/*maintain y*/,
-        d->document->width (),
-        1/*don't care about height*/);
+        static_cast<int> (d->mainView->transformViewToDocY (d->scrollView->verticalScrollBar()->value ()))/*maintain y*/,
+                d->document->width (),
+                1/*don't care about height*/);
     zoomToRect (
         docRect,
         true/*account for grips*/,
@@ -585,10 +575,10 @@ void kpMainWindow::slotFitToHeight ()
   if ( d->document )
   {
     const QRect docRect (
-        (int) d->mainView->transformViewToDocX (d->scrollView->horizontalScrollBar()->value ())/*maintain x*/,
-        0/*y*/,
-        1/*don't care about width*/,
-        d->document->height ());
+        static_cast<int> (d->mainView->transformViewToDocX (d->scrollView->horizontalScrollBar()->value ()))/*maintain x*/,
+                0/*y*/,
+                1/*don't care about width*/,
+                d->document->height ());
     zoomToRect (
         docRect,
         true/*account for grips*/,
@@ -604,13 +594,13 @@ void kpMainWindow::zoomIn (bool centerUnderCursor)
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "kpMainWindow::zoomIn(centerUnderCursor="
               << centerUnderCursor << ") currentItem="
-              << d->actionZoom->currentItem ()
-              << endl;
+              << d->actionZoom->currentItem ();
 #endif
     const int targetItem = d->actionZoom->currentItem () + 1;
 
-    if (targetItem >= (int) d->zoomList.count ())
+    if (targetItem >= static_cast<int> (d->zoomList.count ())) {
         return;
+    }
 
     d->actionZoom->setCurrentItem (targetItem);
 
@@ -629,13 +619,13 @@ void kpMainWindow::zoomOut (bool centerUnderCursor)
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "kpMainWindow::zoomOut(centerUnderCursor="
               << centerUnderCursor << ") currentItem="
-              << d->actionZoom->currentItem ()
-              << endl;
+              << d->actionZoom->currentItem ();
 #endif
     const int targetItem = d->actionZoom->currentItem () - 1;
 
-    if (targetItem < 0)
+    if (targetItem < 0) {
         return;
+    }
 
     d->actionZoom->setCurrentItem (targetItem);
 
@@ -679,8 +669,7 @@ void kpMainWindow::zoomAccordingToZoomAction (bool centerUnderCursor)
     qCDebug(kpLogMainWindow) << "kpMainWindow::zoomAccordingToZoomAction(centerUnderCursor="
               << centerUnderCursor
               << ") currentItem=" << d->actionZoom->currentItem ()
-              << " currentText=" << d->actionZoom->currentText ()
-              << endl;
+              << " currentText=" << d->actionZoom->currentText ();
 #endif
 
     // This might be a new zoom level the user has typed in.
@@ -695,7 +684,7 @@ void kpMainWindow::slotZoom ()
 {
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "kpMainWindow::slotZoom () index=" << d->actionZoom->currentItem ()
-               << " text='" << d->actionZoom->currentText () << "'" << endl;
+               << " text='" << d->actionZoom->currentText () << "'";
 #endif
 
     zoomAccordingToZoomAction (false/*don't center under cursor*/);
