@@ -46,9 +46,9 @@
 #include "kpLogCategories.h"
 #include <KLocalizedString>
 
-#include <qpoint.h>
-#include <qrect.h>
-#include <qtimer.h>
+#include <QPoint>
+#include <QRect>
+#include <QTimer>
 
 //---------------------------------------------------------------------
 
@@ -60,7 +60,7 @@ kpToolSpraycan::kpToolSpraycan (kpToolEnvironment *environ, QObject *parent)
 {
     m_timer = new QTimer (this);
     m_timer->setInterval (25/*ms*/);
-    connect (m_timer, SIGNAL (timeout()), this, SLOT (timeoutDraw()));
+    connect (m_timer, &QTimer::timeout, this, &kpToolSpraycan::timeoutDraw);
 }
 
 //---------------------------------------------------------------------
@@ -80,8 +80,8 @@ void kpToolSpraycan::begin ()
     Q_ASSERT (tb);
 
     m_toolWidgetSpraycanSize = tb->toolWidgetSpraycanSize ();
-    connect (m_toolWidgetSpraycanSize, SIGNAL (spraycanSizeChanged(int)),
-            this, SLOT (slotSpraycanSizeChanged(int)));
+    connect (m_toolWidgetSpraycanSize, &kpToolWidgetSpraycanSize::spraycanSizeChanged,
+             this, &kpToolSpraycan::slotSpraycanSizeChanged);
     m_toolWidgetSpraycanSize->show ();
 
     kpToolFlowBase::begin ();
@@ -92,8 +92,9 @@ void kpToolSpraycan::end ()
 {
     kpToolFlowBase::end ();
 
-    disconnect (m_toolWidgetSpraycanSize, SIGNAL (spraycanSizeChanged(int)),
-                this, SLOT (slotSpraycanSizeChanged(int)));
+    disconnect (m_toolWidgetSpraycanSize, &kpToolWidgetSpraycanSize::spraycanSizeChanged,
+                this, &kpToolSpraycan::slotSpraycanSizeChanged);
+
     m_toolWidgetSpraycanSize = nullptr;
 }
 
@@ -121,7 +122,7 @@ QRect kpToolSpraycan::drawLineWithProbability (const QPoint &thisPoint,
 #if DEBUG_KP_TOOL_SPRAYCAN
     qCDebug(kpLogTools) << "CALL(thisPoint=" << thisPoint
                << ",lastPoint=" << lastPoint
-               << ")" << endl;
+               << ")";
 #endif
 
     QList <QPoint> docPoints = kpPainter::interpolatePoints (lastPoint, thisPoint,
@@ -133,8 +134,9 @@ QRect kpToolSpraycan::drawLineWithProbability (const QPoint &thisPoint,
 
 
     // By chance no points to draw?
-    if (docPoints.empty ())
-        return QRect ();
+    if (docPoints.empty ()) {
+        return  {};
+    }
 
 
     // For efficiency, only get image after NOP check above.
@@ -150,7 +152,7 @@ QRect kpToolSpraycan::drawLineWithProbability (const QPoint &thisPoint,
     //                  appearance.
 
     QList <QPoint> imagePoints;
-    foreach (const QPoint &dp, docPoints)
+    for (const auto &dp : docPoints)
         imagePoints.append (dp - docRect.topLeft ());
 
     kpPainter::sprayPoints (&image,
@@ -172,8 +174,7 @@ QRect kpToolSpraycan::drawPoint (const QPoint &point)
 {
 #if DEBUG_KP_TOOL_SPRAYCAN
     qCDebug(kpLogTools) << "kpToolSpraycan::drawPoint" << point
-               << " lastPoint=" << lastPoint ()
-               << endl;
+               << " lastPoint=" << lastPoint ();
 #endif
 
     // If this is the first in the flow or if the user is moving the spray,
@@ -185,7 +186,7 @@ QRect kpToolSpraycan::drawPoint (const QPoint &point)
             1.0/*100% chance of drawing*/);
     }
 
-    return QRect ();
+    return  {};
 }
 
 // public virtual [base kpToolFlowBase]
@@ -234,7 +235,7 @@ void kpToolSpraycan::endDraw (const QPoint &thisPoint,
 {
 #if DEBUG_KP_TOOL_SPRAYCAN
     qCDebug(kpLogTools) << "kpToolSpraycan::endDraw(thisPoint=" << thisPoint
-               << ")" << endl;
+               << ")";
 #endif
 
     m_timer->stop ();
